@@ -47,29 +47,29 @@ ParameterList CliPlugin::parameterList() const
 
     if (p.isEmpty()) {
         p[CaptureProgress] = true;
-        p[ListProgram] = p[ExtractProgram] = p[DeleteProgram] = p[AddProgram] = "rar";
+        p[ListProgram] = p[ExtractProgram] = p[DeleteProgram] = p[AddProgram] = QLatin1String("rar");
 
-        p[ListArgs] = QStringList() << "v" << "-c-" << "$Archive";
-        p[ExtractArgs] = QStringList() << "-p-" << "$PreservePathSwitch" << "$PasswordSwitch" << "$RootNodeSwitch" << "$Archive" << "$Files";
-        p[PreservePathSwitch] = QStringList() << "x" << "e";
-        p[RootNodeSwitch] = QStringList() << "-ap$Path";
-        p[PasswordSwitch] = QStringList() << "-p$Password";
+        p[ListArgs] = QStringList() << QLatin1String("v") << QLatin1String("-c-") << QLatin1String("$Archive");
+        p[ExtractArgs] = QStringList() << QLatin1String("-p-") << QLatin1String("$PreservePathSwitch") << QLatin1String("$PasswordSwitch") << QLatin1String("$RootNodeSwitch") << QLatin1String("$Archive") << QLatin1String("$Files");
+        p[PreservePathSwitch] = QStringList() << QLatin1String("x") << QLatin1String("e");
+        p[RootNodeSwitch] = QStringList() << QLatin1String("-ap$Path");
+        p[PasswordSwitch] = QStringList() << QLatin1String("-p$Password");
 
-        p[DeleteArgs] = QStringList() << "d" << "$Archive" << "$Files";
+        p[DeleteArgs] = QStringList() << QLatin1String("d") << QLatin1String("$Archive") << QLatin1String("$Files");
 
-        p[FileExistsExpression] = "^(.+) already exists. Overwrite it";
+        p[FileExistsExpression] = QLatin1String("^(.+) already exists. Overwrite it");
         p[FileExistsInput] = QStringList()
-                                << "Y" //overwrite
-                                << "N" //skip
-                                << "A" //overwrite all
-                                << "E" //autoskip
-                                << "Q" //cancel
+                                << QLatin1String("Y") //overwrite
+                                << QLatin1String("N") //skip
+                                << QLatin1String("A") //overwrite all
+                                << QLatin1String("E") //autoskip
+                                << QLatin1String("Q") //cancel
                                 ;
 
-        p[AddArgs] = QStringList() << "a" << "$Archive" << "$Files";
+        p[AddArgs] = QStringList() << QLatin1String("a") << QLatin1String("$Archive") << QLatin1String("$Files");
 
-        p[WrongPasswordPatterns] = QStringList() << "password incorrect";
-        p[ExtractionFailedPatterns] = QStringList() << "CRC failed";
+        p[WrongPasswordPatterns] = QStringList() << QLatin1String("password incorrect");
+        p[ExtractionFailedPatterns] = QStringList() << QLatin1String("CRC failed");
     }
 
     return p;
@@ -77,7 +77,7 @@ ParameterList CliPlugin::parameterList() const
 
 bool CliPlugin::readListLine(const QString &line)
 {
-    const QString m_headerString = "-----------------------------------------";
+    const QString m_headerString = QLatin1String("-----------------------------------------");
 
     // skip the heading
     if (!m_incontent) {
@@ -97,7 +97,7 @@ bool CliPlugin::readListLine(const QString &line)
     if (m_isFirstLine) {
         m_internalId = line.trimmed();
         //m_entryFilename.chop(1); // handle newline
-        if (!m_internalId.isEmpty() && m_internalId.at(0) == '*') {
+        if (!m_internalId.isEmpty() && m_internalId.at(0) == QLatin1Char('*')) {
             m_isPasswordProtected = true;
             m_internalId.remove(0, 1);   // and the spaces in front
         } else
@@ -107,12 +107,12 @@ bool CliPlugin::readListLine(const QString &line)
         return true;
     }
 
-    QStringList fileprops = line.split(' ', QString::SkipEmptyParts);
+    QStringList fileprops = line.split(QLatin1Char(' '), QString::SkipEmptyParts);
     m_internalId = QDir::fromNativeSeparators(m_internalId);
-    bool isDirectory = (bool)(fileprops[ 5 ].contains('d', Qt::CaseInsensitive));
+    bool isDirectory = (bool)(fileprops[ 5 ].contains(QLatin1Char('d'), Qt::CaseInsensitive));
 
-    QDateTime ts(QDate::fromString(fileprops[ 3 ], "dd-MM-yy"),
-                    QTime::fromString(fileprops[ 4 ], "hh:mm"));
+    QDateTime ts(QDate::fromString(fileprops[ 3 ], QLatin1String("dd-MM-yy")),
+                 QTime::fromString(fileprops[ 4 ], QLatin1String("hh:mm")));
     // rar output date with 2 digit year but QDate takes is as 19??
     // let's take 1950 is cut-off; similar to KDateTime
     if (ts.date().year() < 1950) {
@@ -120,8 +120,8 @@ bool CliPlugin::readListLine(const QString &line)
     }
 
     m_entryFilename = m_internalId;
-    if (isDirectory && !m_internalId.endsWith('/')) {
-        m_entryFilename += '/';
+    if (isDirectory && !m_internalId.endsWith(QLatin1Char('/'))) {
+        m_entryFilename += QLatin1Char('/');
     }
 
     //kDebug() << m_entryFilename << " : " << fileprops;
@@ -140,7 +140,7 @@ bool CliPlugin::readListLine(const QString &line)
     e[ IsPasswordProtected] = m_isPasswordProtected;
     kDebug() << "Added entry: " << e;
 
-    entry(e);
+    emit entry(e);
     m_isFirstLine = true;
     return true;
 }
